@@ -30,6 +30,7 @@ from calculate.lib.utils.common import getValueFromConfig, getValueFromCmdLine
 from calculate.lib.utils.common import getUserPrimaryGroup
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.device import getUdevDeviceInfo
+from calculate.lib.variables.system import RootType
 from autopartition import SchemeOpt, SchemeDevices
 from calculate.lib.encrypt import get_shadow_hash, get_grub_hash
 import calculate.lib.cl_ini_parser as cl_ini_parser
@@ -192,7 +193,8 @@ class VariableClGrubPasswdSet(GrubHelper, Variable):
         self.label = _("Use root password for editing grub menu")
 
     def get(self):
-        if path.exists(self.grub_passwd_file):
+        if (path.exists(self.grub_passwd_file) or
+                    self.Get('os_root_type_ext') in RootType.Live):
             return Variable.On
         else:
             return Variable.Off
